@@ -147,8 +147,9 @@ game_find_script_by_hash() {
 	scripts_list="$1"
 
 	# Compute the hash of the current archive
-	local archive_hash
-	archive_hash=$(archive_hash_md5_computed 'SOURCE_ARCHIVE')
+	local archive_name archive_hash
+	archive_name=$(archive_name 'SOURCE_ARCHIVE')
+	archive_hash=$(archive_hash_md5_computed "$archive_name")
 
 	local regexp
 	regexp="^ARCHIVE_BASE(_[A-Z0-9]+)*_[0-9]+_MD5=['\"]?${archive_hash}['\"]?$"
