@@ -1,3 +1,24 @@
+# Warning - An application category outside of the XDG spec is set.
+# USAGE: warning_application_category_unspecified
+warning_application_category_unspecified() {
+	local application application_category
+	application="$1"
+	application_category="$2"
+
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
+		('fr')
+			message='Catégorie inconnue par la spécification pour %s : %s\n'
+		;;
+		('en'|*)
+			message='Unspecified application category for %s: %s\n'
+		;;
+	esac
+	print_message 'warning' "$message" \
+		"$application" "$application_category"
+}
+
 # Error - An unknown application type is used
 # USAGE: error_unknown_application_type $app_type
 error_unknown_application_type() {
