@@ -76,10 +76,7 @@ archive_initialize_optional() {
 				('md5')
 					archive_hash_expected=$(get_value "${archive_candidate}_MD5")
 					if [ -n "$archive_hash_expected" ]; then
-						## TODO: archive_hash_md5_computed could be used
-						##       if it relied on the file name instead of the archive identifier.
-						info_archive_hash_computation "$archive_name"
-						archive_candidate_hash_computed=$(md5sum "$archive_path" | awk '{print $1}')
+						archive_candidate_hash_computed=$(archive_hash_md5_computed "$archive_name")
 						if [ "$archive_candidate_hash_computed" != "$archive_hash_expected" ]; then
 							continue
 						fi
@@ -163,16 +160,26 @@ archives_integrity_check() {
 # Check the integrity of all archives, using MD5
 # USAGE: archives_integrity_check_md5
 archives_integrity_check_md5() {
-	local archives_list archive archive_hash_expected archive_hash_computed
+	local archives_list
 	archives_list=$(archives_used_list)
+
+	local archive archive_hashes_list valid_hash_found archive_hash_expected archive_name archive_hash_computed
 	for archive in $archives_list; do
-		archive_hash_expected=$(archive_hash_md5 "$archive")
-		## Skip archives that have no expected MD5 hash set.
-		if [ -z "$archive_hash_expected" ]; then
+		archive_hashes_list=$(archive_hashes_list_md5 "$archive")
+		## Skip archives with no expected hash set.
+		if [ -z "$archive_hashes_list" ]; then
 			continue
 		fi
-		archive_hash_computed=$(archive_hash_md5_computed "$archive")
-		if [ "$archive_hash_computed" != "$archive_hash_expected" ]; then
+		valid_hash_found=0
+		for archive_hash_expected in $archive_hashes_list; do
+			archive_name=$(archive_name "$archive")
+			archive_hash_computed=$(archive_hash_md5_computed "$archive_name")
+			if [ "$archive_hash_computed" = "$archive_hash_expected" ]; then
+				valid_hash_found=1
+				break
+			fi
+		done
+		if [ "$valid_hash_found" -eq 0 ]; then
 			local archive_path
 			archive_path=$(archive_path "$archive")
 			error_hashsum_mismatch "$archive_path"
