@@ -81,7 +81,7 @@ archive_extraction_extra_libpng12() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
@@ -96,7 +96,7 @@ archive_extraction_extra_libssl100() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
@@ -111,7 +111,7 @@ archive_extraction_extra_libssl11() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'egentoo'|'gentoo')
+		('arch'|'gentoo')
 			return 0
 		;;
 	esac
