@@ -25,7 +25,8 @@ visionaire_application_exe() {
 			continue
 		fi
 		## Do not throw an error if no path is found for the current candidate.
-		filename_path=$(application_exe_path "$filename_candidate") 2>/dev/null || true
+		## The output redirection must be done inside the subshell, or bash --posix will ignore it.
+		filename_path=$(application_exe_path "$filename_candidate" 2>/dev/null || true)
 		if [ -n "$filename_path" ]; then
 			application_exe="$filename_candidate"
 			break
