@@ -126,7 +126,7 @@ debian_field_depends() {
 	package="$1"
 
 	local dependencies_list first_item_displayed dependency_string
-	dependencies_list=$(dependencies_debian_full_list "$package")
+	dependencies_list=$(dependencies_full_list_packages "$package")
 	first_item_displayed=0
 	while read -r dependency_string; do
 		if [ -z "$dependency_string" ]; then
