@@ -98,34 +98,6 @@ test_toupper_shell() {
 	_test_toupper_generic 'toupper_shell'
 }
 
-test_guess_tar_implementation() {
-	local PLAYIT_TAR_IMPLEMENTATION
-
-	# Mock GNU tar output
-	tar() {
-		printf 'tar (GNU tar) 1.34
-Copyright © 2021 Free Software Foundation, Inc.
-License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
-This is free software: you are free to change and redistribute it.
-There is NO WARRANTY, to the extent permitted by law.
-
-Written by John Gilmore and Jay Fenlason.
-'
-	}
-	guess_tar_implementation
-	assertEquals 'gnutar' "$PLAYIT_TAR_IMPLEMENTATION"
-	unset PLAYIT_TAR_IMPLEMENTATION
-
-	# Mock BSD tar output
-	tar() {
-		printf 'bsdtar 3.6.2 - libarchive 3.6.2 zlib/1.2.13 liblzma/5.4.0 bz2lib/1.0.8 liblz4/1.9.4 libzstd/1.5.2\n'
-	}
-	guess_tar_implementation
-	assertEquals 'bsdtar' "$PLAYIT_TAR_IMPLEMENTATION"
-
-	unset -f tar
-}
-
 test_file_type() {
 	local file_type
 	file_type=$(file_type 'play.it')
