@@ -11,10 +11,13 @@ oneTimeSetUp() {
 test_requirements_list() {
 	local \
 		requirements_list requirements_list_expected \
-		SCRIPT_DEPS \
+		REQUIREMENTS_LIST \
 		PLAYIT_CONTEXT_ARCHIVE ARCHIVE_BASE_0_EXTRACTOR
 
-	SCRIPT_DEPS='command1 command2 command3'
+	REQUIREMENTS_LIST='
+	command1
+	command2
+	command3'
 	ARCHIVE_BASE_0_EXTRACTOR='unzip'
 	set_current_archive 'ARCHIVE_BASE_0'
 
