@@ -83,39 +83,6 @@ test_archive_size() {
 	assertEquals '0' "$archive_size"
 }
 
-test_archive_hash_md5() {
-	local archive_hash ARCHIVE_BASE_0_MD5
-
-	ARCHIVE_BASE_0_MD5='6c9bd7e1cf88fdbfa0e75f694bf8b0e5'
-	archive_hash=$(archive_hash_md5 'ARCHIVE_BASE_0')
-	assertEquals '6c9bd7e1cf88fdbfa0e75f694bf8b0e5' "$archive_hash"
-}
-
-test_archive_hash_md5_computed() {
-	local archive_hash PLAYIT_WORKDIR ARCHIVE_BASE_0_NAME ARCHIVE_BASE_0_PATH
-
-	PLAYIT_WORKDIR="$TEST_TEMP_DIR"
-	mkdir --parents "${PLAYIT_WORKDIR}/cache"
-	cat >> "${PLAYIT_WORKDIR}/cache/hashes" <<- EOF
-	ARCHIVE_BASE_0 | 6c9bd7e1cf88fdbfa0e75f694bf8b0e5
-	EOF
-	archive_hash=$(archive_hash_md5_computed 'ARCHIVE_BASE_0')
-	assertEquals '6c9bd7e1cf88fdbfa0e75f694bf8b0e5' "$archive_hash"
-	rm "${PLAYIT_WORKDIR}/cache/hashes"
-
-	ARCHIVE_BASE_0_NAME='null'
-	ARCHIVE_BASE_0_PATH='/dev/null'
-	archive_hash=$(archive_hash_md5_computed 'ARCHIVE_BASE_0')
-	assertEquals 'd41d8cd98f00b204e9800998ecf8427e' "$archive_hash"
-
-	local archive_hash_computed
-	unset PLAYIT_WORKDIR
-	archive_hash_computed='d401431ff9c1c7526c3104194409bd6e'
-	archive_hash=$(archive_hash_md5_computed 'ARCHIVE_BASE_0')
-	assertEquals 'Some value of $archive_hash_computed leaked from a broader scope.' \
-		'd41d8cd98f00b204e9800998ecf8427e' "$archive_hash"
-}
-
 test_archive_type() {
 	local ARCHIVE_BASE_0_NAME ARCHIVE_BASE_0_TYPE ARCHIVE_BASE_0_PART1_NAME archive_type
 
