@@ -12,8 +12,8 @@ test_debian_dependency_providing_mono_library() {
 
 	# Check that setting a dependency on an unkown Mono library is allowed
 	assertTrue \
-		'debian_dependency_providing_mono_library choked on an unkwown Mono library.' \
-		'debian_dependency_providing_mono_library "Mono.unknown.dll"'
+		'dependencies_mono_single_debian choked on an unkwown Mono library.' \
+		'dependencies_mono_single_debian "Mono.unknown.dll"'
 
 	unset -f dependencies_unknown_mono_libraries_add
 }
